==> kenga-0.0.51.tgz: package/container.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var utils = require('./utils.js');
var widget = require('./widget.js');
var containerEvent = require('./events/container-event.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default['default'](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default['default'](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default['default'](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var Container = /*#__PURE__*/function (_Widget) {
  _inherits__default['default'](Container, _Widget);

  var _super = _createSuper(Container);

  function Container(shell, content) {
    var _this;

    _classCallCheck__default['default'](this, Container);

    shell = shell || document.createElement('div');
    content = content || shell;
    _this = _super.call(this, shell);

    var self = _assertThisInitialized__default['default'](_this);

    var children = [];

    _this.element.classList.add('p-container');

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'count', {
      get: function get() {
        return children.length;
      }
    });

    function child(index) {
      if (index >= 0 && index < children.length) {
        return children[index];
      } else {
        return null;
      }
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'child', {
      configurable: true,
      get: function get() {
        return child;
      }
    });

    function _children() {
      return children.slice(0, children.length);
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'children', {
      configurable: true,
      get: function get() {
        return _children;
      }
    });

    function forEach(action) {
      children.forEach(action);
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'forEach', {
      get: function get() {
        return forEach;
      }
    });

    function indexOf(w) {
      return children.indexOf(w);
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'indexOf', {
      get: function get() {
        return indexOf;
      }
    });

    function add(w, beforeIndex) {
      if (w.parent === self) throw 'A widget is already child of this container';
      w.parent = self;

      if (isNaN(beforeIndex)) {
        content.appendChild(w.element);
        children.push(w);
      } else {
        if (beforeIndex < children.length) {
          content.insertBefore(w.element, children[beforeIndex].element);
        } else {
          content.appendChild(w.element);
        }

        children.splice(beforeIndex, 0, w);
      }

      fireAdded(w);
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'add', {
      configurable: true,
      get: function get() {
        return add;
      }
    });

    function remove(w) {
      var idx;
      if (w instanceof widget) idx = children.indexOf(w);else idx = w;

      if (idx >= 0 && idx < children.length) {
        var removed = children.splice(idx, 1)[0];
        removed.parent = null;
        removed.element.parentElement.removeChild(removed.element);
        fireRemoved(w);
        return removed;
      } else {
        return null;
      }
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'remove', {
      configurable: true,
      get: function get() {
        return remove;
      }
    });

    function clear() {
      children.forEach(function (child) {
        child.parent = null;
        child.element.parentElement.removeChild(child.element);
        fireRemoved(child);
      });
      children.splice(0, children.length);
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'clear', {
      configurable: true,
      get: function get() {
        return clear;
      }
    });
    var addHandlers = new Set();

    function addAddHandler(handler) {
      addHandlers.add(handler);
      return {
        removeHandler: function removeHandler() {
          addHandlers["delete"](handler);
        }
      };
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'addAddHandler', {
      configurable: true,
      get: function get() {
        return addAddHandler;
      }
    });

    function fireAdded(w) {
      var event = new containerEvent(self, w);
      addHandlers.forEach(function (h) {
        utils.later(function () {
          h(event);
        });
      });
    }

    var onAdd;
    var addReg;
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'onAdd', {
      get: function get() {
        return onAdd;
      },
      set: function set(aValue) {
        if (onAdd !== aValue) {
          if (addReg) {
            addReg.removeHandler();
            addReg = null;
          }

          onAdd = aValue;

          if (onAdd) {
            addReg = addAddHandler(function (event) {
              if (onAdd) {
                onAdd(event);
              }
            });
          }
        }
      }
    });
    var removeHandlers = new Set();

    function addRemoveHandler(handler) {
      removeHandlers.add(handler);
      return {
        removeHandler: function removeHandler() {
          removeHandlers["delete"](handler);
        }
      };
    }

    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'addRemoveHandler', {
      configurable: true,
      get: function get() {
        return addRemoveHandler;
      }
    });

    function fireRemoved(w) {
      var event = new containerEvent(self, w);
      removeHandlers.forEach(function (h) {
        utils.later(function () {
          h(event);
        });
      });
    }

    var onRemove;
    var removeReg;
    Object.defineProperty(_assertThisInitialized__default['default'](_this), 'onRemove', {
      get: function get() {
        return onRemove;
      },
      set: function set(aValue) {
        if (onRemove !== aValue) {
          if (removeReg) {
            removeReg.removeHandler();
            removeReg = null;
          }

          onRemove = aValue;

          if (onRemove) {
            removeReg = addRemoveHandler(function (event) {
              if (onRemove) {
                onRemove(event);
              }
            });
          }
        }
      }
    });
    return _this;
  }

  return Container;
}(widget);

module.exports = Container;

==> kenga-0.0.53.tgz: package/container.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inherits = require('@babel/runtime/helpers/inherits');
var _possibleConstructorReturn = require('@babel/runtime/helpers/possibleConstructorReturn');
var _getPrototypeOf = require('@babel/runtime/helpers/getPrototypeOf');
var utils = require('./utils.js');
var widget = require('./widget.js');
var containerEvent = require('./events/container-event.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inherits__default = /*#__PURE__*/_interopDefaultLegacy(_inherits);
var _possibleConstructorReturn__default = /*#__PURE__*/_interopDefaultLegacy(_possibleConstructorReturn);
var _getPrototypeOf__default = /*#__PURE__*/_interopDefaultLegacy(_getPrototypeOf);

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf__default["default"](Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf__default["default"](this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn__default["default"](this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var Container = /*#__PURE__*/function (_Widget) {
  _inherits__default["default"](Container, _Widget);

  var _super = _createSuper(Container);

  function Container(shell, content) {
    var _this;

    _classCallCheck__default["default"](this, Container);

    shell = shell || document.createElement('div');
    content = content || shell;
    _this = _super.call(this, shell);

    var self = _assertThisInitialized__default["default"](_this);

    var children = [];

    _this.element.classList.add('p-container');

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'count', {
      get: function get() {
        return children.length;
      }
    });

    function child(index) {
      if (index >= 0 && index < children.length) {
        return children[index];
      } else {
        return null;
      }
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'child', {
      configurable: true,
      get: function get() {
        return child;
      }
    });

    function _children() {
      return children.slice(0, children.length);
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'children', {
      configurable: true,
      get: function get() {
        return _children;
      }
    });

    function forEach(action) {
      children.forEach(action);
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'forEach', {
      get: function get() {
        return forEach;
      }
    });

    function indexOf(w) {
      return children.indexOf(w);
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'indexOf', {
      get: function get() {
        return indexOf;
      }
    });

    function add(w, beforeIndex) {
      if (w.parent === self) throw 'A widget is already child of this container';
      w.parent = self;

      if (isNaN(beforeIndex)) {
        content.appendChild(w.element);
        children.push(w);
      } else {
        if (beforeIndex < children.length) {
          content.insertBefore(w.element, children[beforeIndex].element);
        } else {
          content.appendChild(w.element);
        }

        children.splice(beforeIndex, 0, w);
      }

      fireAdded(w);
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'add', {
      configurable: true,
      get: function get() {
        return add;
      }
    });

    function remove(w) {
      var idx;
      if (w instanceof widget) idx = children.indexOf(w);else idx = w;

      if (idx >= 0 && idx < children.length) {
        var removed = children.splice(idx, 1)[0];
        removed.parent = null;
        removed.element.parentElement.removeChild(removed.element);
        fireRemoved(w);
        return removed;
      } else {
        return null;
      }
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'remove', {
      configurable: true,
      get: function get() {
        return remove;
      }
    });

    function clear() {
      children.forEach(function (child) {
        child.parent = null;
        child.element.parentElement.removeChild(child.element);
        fireRemoved(child);
      });
      children.splice(0, children.length);
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'clear', {
      configurable: true,
      get: function get() {
        return clear;
      }
    });
    var addHandlers = new Set();

    function addAddHandler(handler) {
      addHandlers.add(handler);
      return {
        removeHandler: function removeHandler() {
          addHandlers["delete"](handler);
        }
      };
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'addAddHandler', {
      configurable: true,
      get: function get() {
        return addAddHandler;
      }
    });

    function fireAdded(w) {
      var event = new containerEvent(self, w);
      addHandlers.forEach(function (h) {
        utils.later(function () {
          h(event);
        });
      });
    }

    var onAdd;
    var addReg;
    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'onAdd', {
      get: function get() {
        return onAdd;
      },
      set: function set(aValue) {
        if (onAdd !== aValue) {
          if (addReg) {
            addReg.removeHandler();
            addReg = null;
          }

          onAdd = aValue;

          if (onAdd) {
            addReg = addAddHandler(function (event) {
              if (onAdd) {
                onAdd(event);
              }
            });
          }
        }
      }
    });
    var removeHandlers = new Set();

    function addRemoveHandler(handler) {
      removeHandlers.add(handler);
      return {
        removeHandler: function removeHandler() {
          removeHandlers["delete"](handler);
        }
      };
    }

    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'addRemoveHandler', {
      configurable: true,
      get: function get() {
        return addRemoveHandler;
      }
    });

    function fireRemoved(w) {
      var event = new containerEvent(self, w);
      removeHandlers.forEach(function (h) {
        utils.later(function () {
          h(event);
        });
      });
    }

    var onRemove;
    var removeReg;
    Object.defineProperty(_assertThisInitialized__default["default"](_this), 'onRemove', {
      get: function get() {
        return onRemove;
      },
      set: function set(aValue) {
        if (onRemove !== aValue) {
          if (removeReg) {
            removeReg.removeHandler();
            removeReg = null;
          }

          onRemove = aValue;

          if (onRemove) {
            removeReg = addRemoveHandler(function (event) {
              if (onRemove) {
                onRemove(event);
              }
            });
          }
        }
      }
    });
    return _this;
  }

  return Container;
}(widget);

module.exports = Container;
